/*
 * EtherPix config file generator
 *
 * Copyright 2010-2017 Stefan Schuermans <stefan schuermans info>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <math.h>

#include "point.h"

Point::Point():
  mX(0.0),
  mY(0.0)
{
}

Point::Point(double x, double y):
  mX(x),
  mY(y)
{
}

double Point::abs_sq() const
{
  return mX * mX + mY * mY;
}

double Point::abs() const
{
  return sqrt(mX * mX + mY * mY);
}

Point Point::operator-() const
{
  return Point(-mX, -mY);
}

Point Point::operator+(const Point &that) const
{
  return Point(mX + that.mX, mY + that.mY);
}

Point Point::operator-(const Point &that) const
{
  return Point(mX - that.mX, mY - that.mY);
}

Point Point::operator*(double factor) const
{
  return Point(mX * factor, mY * factor);
}

Point Point::operator/(double factor) const
{
  return Point(mX / factor, mY / factor);
}

Point &Point::operator+=(const Point &that)
{
  mX += that.mX;
  mY += that.mY;
  return *this;
}

Point &Point::operator-=(const Point &that)
{
  mX -= that.mX;
  mY -= that.mY;
  return *this;
}

Point &Point::operator*=(double factor)
{
  mX *= factor;
  mY *= factor;
  return *this;
}

Point &Point::operator/=(double factor)
{
  mX /= factor;
  mY /= factor;
  return *this;
}

